Python Library to access AVM Fritz!Box homeautomation
=====================================================

|BuildStatus| |Coveralls| |CodeClimate|

Tested Devices
--------------
* `FRITZ!Box 6490 Cable`_ with FRITZ!OS 06.85
* `FRITZ!DECT 200`_ with firmware 03.87
* `Comet DECT`_ with firmware 03.54

.. |BuildStatus| image:: https://travis-ci.org/hthiery/python-fritzhome.png?branch=master
                 :target: https://travis-ci.org/hthiery/python-fritzhome
.. |CodeClimate| image:: https://api.codeclimate.com/v1/badges/fc83491ef0ae81080882/maintainability
				 :target: https://codeclimate.com/github/hthiery/python-fritzhome/maintainability
				 :alt: Maintainability
.. |Coveralls|   image:: https://coveralls.io/repos/github/hthiery/python-fritzhome/badge.svg?branch=master
                 :target: https://coveralls.io/github/hthiery/python-fritzhome?branch=master

.. _Comet DECT: https://www.eurotronic.org/produkte/comet-dect.html
.. _FRITZ!DECT 200: https://avm.de/produkte/fritzdect/fritzdect-200/
.. _FRITZ!Box 6490 Cable: https://avm.de/produkte/fritzbox/fritzbox-6490-cable/
